import { IsString } from 'class-validator';
import { NotAcceptableError, NotFoundError } from 'routing-controllers';


/**
 * Error to throw when no username or email is set.
 * We somehow need to identify you :)
 */
export class UsernameOrEmailNeededError extends NotFoundError {
	@IsString()
	name = "UsernameOrEmailNeededError"

	@IsString()
	message = "No username or email is set!"
}

/**
 * Error to throw when a user couldn't be found.
 */
export class UserNotFoundError extends NotFoundError {
	@IsString()
	name = "UserNotFoundError"

	@IsString()
	message = "User not found!"
}

/**
 * Error to throw when two users' ids don't match.
 * Usually occurs when a user tries to change a user's id.
 */
export class UserIdsNotMatchingError extends NotAcceptableError {
	@IsString()
	name = "UserIdsNotMatchingError"

	@IsString()
	message = "The ids don't match!! \n And if you wanted to change a user's id: This isn't allowed!"
}