import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
    const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
    access_token = res.data["access_token"];
    axios_config = {
        headers: { "authorization": "Bearer " + access_token },
        validateStatus: undefined
    };
});

describe('GET /api/teams', () => {
    it('basic get should return 200', async () => {
        const res = await axios.get(base + '/api/teams', axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('GET /api/teams/0', () => {
    it('basic get should return 404', async () => {
        const res = await axios.get(base + '/api/teams/0', axios_config);
        expect(res.status).toEqual(404);
        expect(res.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('POST /api/teams with errors', () => {
    it('creating a new team without a name should return 400', async () => {
        const res1 = await axios.post(base + '/api/teams', {
            "name": null
        }, axios_config);
        expect(res1.status).toEqual(400);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new team without a org should return 400', async () => {
        const res2 = await axios.post(base + '/api/teams', {
            "name": "test_team"
        }, axios_config);
        expect(res2.status).toEqual(400);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('creating a new team without a valid org should return 404', async () => {
        const res3 = await axios.post(base + '/api/teams', {
            "name": "test_team",
            "parentGroup": -1
        }, axios_config);
        expect(res3.status).toEqual(404);
        expect(res3.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('POST /api/teams working', () => {
    let added_org_id;
    it('creating a new org with just a name should return 200', async () => {
        const res1 = await axios.post(base + '/api/organisations', {
            "name": "test123"
        }, axios_config);
        let added_org = res1.data
        added_org_id = added_org.id;
        expect(res1.status).toEqual(200);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new team with a parent org should return 200', async () => {
        const res2 = await axios.post(base + '/api/teams', {
            "name": "test_team",
            "parentGroup": added_org_id
        }, axios_config);
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
});