import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
    const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
    access_token = res.data["access_token"];
    axios_config = {
        headers: { "authorization": "Bearer " + access_token },
        validateStatus: undefined
    };
});
// ---------------
describe('adding + updating name', () => {
    let added_org;
    let added_org_id;
    let added_team;
    let added_team_id
    it('creating a new org with just a name should return 200', async () => {
        const res1 = await axios.post(base + '/api/organisations', {
            "name": "test123"
        }, axios_config);
        added_org = res1.data;
        added_org_id = added_org.id;
        expect(res1.status).toEqual(200);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new team with a valid org should return 200', async () => {
        const res2 = await axios.post(base + '/api/teams', {
            "name": "test123",
            "parentGroup": added_org_id
        }, axios_config);
        added_team = res2.data;
        added_team_id = added_team.id;
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('update name', async () => {
        const res3 = await axios.put(base + '/api/teams/' + added_team_id, {
            "id": added_team_id,
            "name": "testlelele",
            "contact": null,
            "parentGroup": added_org
        }, axios_config);
        expect(res3.status).toEqual(200);
        expect(res3.headers['content-type']).toContain("application/json")
        let updated_team = res3.data;
        added_team.name = "testlelele";
        expect(updated_team).toEqual(added_team)
    });
});
// ---------------
describe('adding + try updating id (should return 406)', () => {
    let added_org;
    let added_org_id;
    let added_team;
    let added_team_id
    it('creating a new org with just a name should return 200', async () => {
        const res1 = await axios.post(base + '/api/organisations', {
            "name": "test123"
        }, axios_config);
        added_org = res1.data;
        added_org_id = added_org.id;
        expect(res1.status).toEqual(200);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new team with a valid org should return 200', async () => {
        const res2 = await axios.post(base + '/api/teams', {
            "name": "test123",
            "parentGroup": added_org_id
        }, axios_config);
        added_team = res2.data;
        added_team_id = added_team.id;
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('update team', async () => {
        added_team.id = added_team.id + 1;
        const res3 = await axios.put(base + '/api/teams/' + added_team_id, added_team, axios_config);
        expect(res3.status).toEqual(406);
        expect(res3.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('add+update parent org (valid)', () => {
    let added_org;
    let added_org2;
    let added_team;
    let added_team_id
    it('creating a new org with just a name should return 200', async () => {
        const res1 = await axios.post(base + '/api/organisations', {
            "name": "test123"
        }, axios_config);
        added_org = res1.data;
        expect(res1.status).toEqual(200);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new team with a valid org should return 200', async () => {
        const res2 = await axios.post(base + '/api/teams', {
            "name": "test123",
            "parentGroup": added_org.id
        }, axios_config);
        added_team = res2.data;
        added_team_id = added_team.id;
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('creating a new org with just a name should return 200', async () => {
        const res3 = await axios.post(base + '/api/organisations', {
            "name": "test123"
        }, axios_config);
        added_org2 = res3.data;
        expect(res3.status).toEqual(200);
        expect(res3.headers['content-type']).toContain("application/json")
    });
    it('update team', async () => {
        added_team.parentGroup = added_org2;
        const res4 = await axios.put(base + '/api/teams/' + added_team_id, added_team, axios_config);
        let updated_team = res4.data;
        expect(res4.status).toEqual(200);
        expect(res4.headers['content-type']).toContain("application/json")
        delete added_org2.address;
        delete added_org2.contact;
        delete added_org2.teams;
        expect(updated_team).toEqual(added_team)
    });
});