import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
    const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
    access_token = res.data["access_token"];
    axios_config = {
        headers: { "authorization": "Bearer " + access_token },
        validateStatus: undefined
    };
});

describe('adding + deletion (non-existant)', () => {
    it('delete', async () => {
        const res2 = await axios.delete(base + '/api/runners/0', axios_config);
        expect(res2.status).toEqual(204);
    });
});
// ---------------
describe('add+delete', () => {
    let added_org_id;
    let added_runner;
    it('creating a new org with just a name should return 200', async () => {
        const res1 = await axios.post(base + '/api/organisations', {
            "name": "test123"
        }, axios_config);
        let added_org = res1.data
        added_org_id = added_org.id;
        expect(res1.status).toEqual(200);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new runner with only needed params should return 200', async () => {
        const res2 = await axios.post(base + '/api/runners', {
            "firstname": "first",
            "lastname": "last",
            "group": added_org_id
        }, axios_config);
        added_runner = res2.data;
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('delete runner', async () => {
        const res3 = await axios.delete(base + '/api/runners/' + added_runner.id, axios_config);
        expect(res3.status).toEqual(200);
        expect(res3.headers['content-type']).toContain("application/json")
        let deleted_runner = res3.data
        expect(deleted_runner).toEqual(added_runner);
    });
    it('check if team really was deleted', async () => {
        const res4 = await axios.get(base + '/api/runners/' + added_runner.id, axios_config);
        expect(res4.status).toEqual(404);
        expect(res4.headers['content-type']).toContain("application/json")
    });
});